<template>
  <div>
    <el-timeline>
      <el-timeline-item
        v-for="(log, index) in logList"
        :key="index"
        :color="getColor(log)"
        placement="top"
        :timestamp="log.gmtCreate">
        <div class="log" v-if="log.eventType === 'FINISHED'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag op">完成</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'REJECT'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag reject">驳回</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag reject">驳回原因</span>
            ：
            <span class="tag">{{log.eventDataObj.reason}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'HANGUP'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag reject">挂起</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag reject">挂起原因</span>
            ：
            <span class="tag">{{log.eventDataObj.reason}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'CANCEL_HANGUP'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag reject">取消挂起</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'DELEGATE'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            将任务
            <span class="tag taskName">{{log.taskName}}</span>
            <span class="tag op">转办</span>
            给了
            <span class="tag">{{log.eventDataObj.afterHandlerNames.join('、')}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'JUMP'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag jump">跳过</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag jump">跳过说明</span>
            ：
            <span class="tag">{{log.eventDataObj.desc}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'WAIT'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag jump">容缺</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag jump">容缺说明</span>
            ：
            <span class="tag">{{log.eventDataObj.desc}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'SUPERVISE'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag db">督办</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag db">督办信息</span>
            ：
            <span class="tag">{{log.eventDataObj.content}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'EDIT'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            <span class="tag db">修改</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'TEAM_WORK'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            邀请了谁谁谁
            <span class="tag op">协同办理</span>
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
      </el-timeline-item>
    </el-timeline>
  </div>
</template>

<script>
export default {
  name: "LogTimeLine",
  props: {
    logList: {
      require: true,
      type: Array
    }
  },
  data() {
    return {

    }
  },
  methods: {
    getColor(log) {
      if (log.eventType === 'FINISHED') {
        return "#67C23A"
      } else if (log.eventType === 'REJECT' || log.eventType === 'EDIT') {
        return "#F56C6C"
      } else if (log.eventType === 'HANGUP') {
        return "#409EFF"
      } else if (log.eventType === 'CANCEL_HANGUP') {
        return "#409EFF"
      } else if (log.eventType === 'DELEGATE') {
        return "#53b1d3"
      } else if (log.eventType === 'JUMP' || log.eventType === 'WAIT') {
        return "#E6A23C"
      } else if (log.eventType === 'SUPERVISE') {
        return "#F56C6C"
      } else if (log.eventType === 'TEAM_WORK') {
        return "#909399"
      }
    }
  }
}
</script>

<style scoped>
.log {
  color: #606266;
}
.tag {
  margin: 0 5px;
}
</style>
